@@ -99,7 +99,9 @@ class DataLoader(_DataLoader):
                  worker_init_fn: Optional[Callable] = None,
                  multiprocessing_context=None,
                  auto_convert: bool = True,
-                 transform_call: Callable[[Any, Callable], Any] = default_transform_call):
+                 transform_call: Callable[[Any, Callable], Any] = default_transform_call,
+                 **kwargs
+                 ):
         """
         Args:
             dataset: dataset from which to load the data
@@ -163,7 +165,7 @@ class DataLoader(_DataLoader):
                          collate_fn=collate_fn, pin_memory=pin_memory,
                          drop_last=drop_last, timeout=timeout,
                          worker_init_fn=worker_init_fn,
-                         multiprocessing_context=multiprocessing_context)
+                         multiprocessing_context=multiprocessing_context, **kwargs)
 
         if gpu_transforms is not None and not torch.cuda.is_available():
             if hasattr(gpu_transforms, 'to'):
@@ -187,6 +189,7 @@ class DataLoader(_DataLoader):
             gpu_transforms = Compose(to_gpu_trafo, gpu_transforms)
             gpu_transforms = gpu_transforms.to(device)
 
+        self.device = device
         self.sample_transforms = sample_transforms
         self.pseudo_batch_dim = pseudo_batch_dim and sample_transforms is not None
         self.gpu_transforms = gpu_transforms
